@@ -94,7 +94,7 @@ static volatile AO_T sigaction_called = 0;
  */
 
 # include <errno.h>
-# include <perfmon/pfmlib.h>
+# include <perfmon2/pfmlib.h>
 # include <dlfcn.h>
 
 /* The following may be written repeatedly by different threads.	*/
@@ -126,9 +126,9 @@ QPROF_setup_hw_event (long interval)
   typeof(pfm_dispatch_events) * my_pfm_dispatch_events;
 
   if (0 == event_string) return 0;
-  if ((pfm_handle = dlopen("libpfm.so.2", RTLD_LAZY)) == NULL)
+  if ((pfm_handle = dlopen("libpfm.2so.2", RTLD_LAZY)) == NULL)
     {
-      QPROF_warn("Can't load libpfm: using timer instead.\n");
+      QPROF_warn("Can't load libpfm2: using timer instead.\n");
       return 0;
     }
   my_pfm_initialize = dlsym(pfm_handle, "pfm_initialize");
@@ -143,7 +143,7 @@ QPROF_setup_hw_event (long interval)
   if (!my_pfm_initialize || !my_pfm_find_event || !my_pfm_dispatch_events
       || !my_perfmonctl /* || !my_pfm_start || !my_pfm_stop */)
     {
-      QPROF_warn("Missing libpfm symbol: using timer instead.\n");
+      QPROF_warn("Missing libpfm2 symbol: using timer instead.\n");
       return 0;
     }
   if (my_pfm_initialize() != PFMLIB_SUCCESS)
@@ -616,6 +616,10 @@ add_sample(unsigned long pc)
 # define SET_PC \
     struct sigcontext *sc = (struct sigcontext *) &si; \
     unsigned long pc = (AO_T)(sc->eip)
+#elif defined(__x86_64__)
+# define SET_PC \
+    struct sigcontext *sc = (struct sigcontext *) &si; \
+    unsigned long pc = (AO_T)(sc->rip)
 #elif defined(__ia64__)
 # define SET_PC \
     struct sigcontext *sc = (struct sigcontext *) scv; \
@@ -629,6 +633,10 @@ add_sample(unsigned long pc)
     /* which appears to work on 32 bit kernels.  As I recall, we should */
     /* be using ucontext_t * as the type of the last argument.  But it	*/
     /* appears hard to extract iaoq[0] fromt that.			*/
+#elif defined(__sparc__)
+# define SET_PC \
+    struct sigcontext *sc = (struct sigcontext *) scv; \
+    unsigned long pc = (AO_T)(sc->si_regs.pc)
 #else
 # define SET_PC \
     struct sigcontext *sc = (struct sigcontext *) scv; \
