@@ -29,6 +29,7 @@
  * SOFTWARE. 
  */
 
+#include "config.h"
 #include "prof_utils.h"
 #include "q-lib.h"
 
@@ -101,8 +102,8 @@ static volatile AO_T sigaction_called = 0;
  */
 
 # include <errno.h>
-# include <perfmon/pfmlib.h>
-# include <perfmon/perfmon.h>
+# include <perfmon3/pfmlib.h>
+# include <perfmon3/perfmon.h>
 # include <dlfcn.h>
 # include <fcntl.h>
 # include <asm/unistd.h>
@@ -152,9 +153,9 @@ QPROF_setup_hw_event (long interval)
   typeof(pfm_dispatch_events) * my_pfm_dispatch_events;
 
   if (0 == event_string) return 0;
-  if ((pfm_handle = dlopen("libpfm.so.3", RTLD_LAZY)) == NULL)
+  if ((pfm_handle = dlopen("libpfm3.so.3", RTLD_LAZY)) == NULL)
     {
-      QPROF_warn("Can't load libpfm: using timer instead.\n");
+      QPROF_warn("Can't load libpfm3: using timer instead.\n");
       return 0;
     }
   my_pfm_initialize = dlsym(pfm_handle, "pfm_initialize");
@@ -167,7 +168,7 @@ QPROF_setup_hw_event (long interval)
   if (!my_pfm_initialize || !my_pfm_find_event || !my_pfm_dispatch_events
       || !my_perfmonctl /* || !my_pfm_start || !my_pfm_stop */)
     {
-      QPROF_warn("Missing libpfm symbol: using timer instead.\n");
+      QPROF_warn("Missing libpfm3 symbol: using timer instead.\n");
       return 0;
     }
   if (my_pfm_initialize() != PFMLIB_SUCCESS)
@@ -694,6 +695,10 @@ add_sample(unsigned long pc)
 # define SET_PC \
     struct sigcontext *sc = (struct sigcontext *) &si; \
     unsigned long pc = (AO_T)(sc->eip)
+#elif defined(__x86_64__)
+# define SET_PC \
+    struct sigcontext *sc = (struct sigcontext *) &si; \
+    unsigned long pc = (AO_T)(sc->rip)
 #elif defined(__ia64__)
 # define SET_PC \
     struct sigcontext *sc = (struct sigcontext *) scv; \
@@ -707,6 +712,10 @@ add_sample(unsigned long pc)
     /* which appears to work on 32 bit kernels.  As I recall, we should */
     /* be using ucontext_t * as the type of the last argument.  But it	*/
     /* appears hard to extract iaoq[0] fromt that.			*/
+#elif defined(__sparc__)
+# define SET_PC \
+    struct sigcontext *sc = (struct sigcontext *) scv; \
+    unsigned long pc = (AO_T)(sc->si_regs.pc)
 #else
 # define SET_PC \
     struct sigcontext *sc = (struct sigcontext *) scv; \
